==> trade-center-biz-0.2.0-20161107.064854-2-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteOrdersFasterSimpleServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.dto.OrdersFasterDto;
import cn.com.duiba.order.center.api.remoteservice.RemoteOrdersFasterSimpleService;
import cn.com.duiba.order.center.biz.service.credits.OrdersFasterSimpleService;
import cn.com.duiba.wolf.dubbo.DubboResult;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * Created by yansen on 16/9/23.
 */
@Service
public class RemoteOrdersFasterSimpleServiceImpl implements RemoteOrdersFasterSimpleService {

    @Autowired
    private OrdersFasterSimpleService ordersFasterSimpleService;

    @Override
    public DubboResult<OrdersFasterDto> insert(OrdersFasterDto ordersFasterDto) {
         ordersFasterSimpleService.insert(ordersFasterDto);
        return DubboResult.successResult(ordersFasterDto);
    }

    @Override
    public DubboResult<OrdersFasterDto> findByOrderIdAndFastertype(Long orderId, Integer fasterType) {
        return DubboResult.successResult(ordersFasterSimpleService.findByOrderIdAndFastertype(orderId,fasterType));
    }

    @Override
    public DubboResult<Integer> updateLastSendTime(Long id, Date lastSendTime) {
        return DubboResult.successResult(ordersFasterSimpleService.updateLastSendTime(id,lastSendTime));
    }

	@Override
	public DubboResult<Integer> deleteOrderByOrderIdAndFasterType(Long orderId, Integer fasterType) {
        return DubboResult.successResult(ordersFasterSimpleService.deleteOrderByOrderIdAndFasterType(orderId,fasterType));
	}
}

==> trade-center-biz-0.5.3-20161220.020755-1-sources.jar: cn/com/duiba/order/center/biz/remoteservice/RemoteOrdersFasterSimpleServiceImpl.java <==
package cn.com.duiba.order.center.biz.remoteservice;

import cn.com.duiba.order.center.api.dto.OrdersFasterDto;
import cn.com.duiba.order.center.api.remoteservice.RemoteOrdersFasterSimpleService;
import cn.com.duiba.order.center.biz.service.credits.OrdersFasterSimpleService;
import cn.com.duiba.wolf.dubbo.DubboResult;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * Created by yansen on 16/9/23.
 */
@Service
public class RemoteOrdersFasterSimpleServiceImpl implements RemoteOrdersFasterSimpleService {

    @Autowired
    private OrdersFasterSimpleService ordersFasterSimpleService;

    @Override
    public DubboResult<OrdersFasterDto> insert(OrdersFasterDto ordersFasterDto) {
        ordersFasterSimpleService.insert(ordersFasterDto);
        return DubboResult.successResult(ordersFasterDto);
    }

    @Override
    public DubboResult<OrdersFasterDto> findByOrderIdAndFastertype(Long orderId, Integer fasterType) {
        return DubboResult.successResult(ordersFasterSimpleService.findByOrderIdAndFastertype(orderId,fasterType));
    }

    @Override
    public DubboResult<Integer> updateLastSendTime(Long id, Date lastSendTime) {
        return DubboResult.successResult(ordersFasterSimpleService.updateLastSendTime(id,lastSendTime));
    }

	@Override
	public DubboResult<Integer> deleteOrderByOrderIdAndFasterType(Long orderId, Integer fasterType) {
        return DubboResult.successResult(ordersFasterSimpleService.deleteOrderByOrderIdAndFasterType(orderId,fasterType));
	}

    @Override
    public DubboResult<List<OrdersFasterDto>> findHuiChangeAndSuDuDaTimeOutOrder(Integer fasterType) {
        return DubboResult.successResult(ordersFasterSimpleService.findHuiChangeAndSuDuDaTimeOutOrder(fasterType));
    }

    @Override
    public DubboResult<Void> deleteOrderFast(Long orderId) {
        ordersFasterSimpleService.deleteOrderFast(orderId);
        return DubboResult.successResult(null);
    }
}
